import { ListPage } from "./list.po";
import { CalculatorPage } from "./calculator.po";
import { Navbar } from "./navbar.po";
import { browser } from "protractor";
import { PreferencesPage } from "./preferences.po";
import { testedCalcTypes } from "./tested_calctypes";
import { scrollPageToTop } from "./util.po";

/**
 * Clone calculators
 */
describe("ngHyd − clone all calculators with all possible <select> values", () => {
    let listPage: ListPage;
    let calcPage: CalculatorPage;
    let navbar: Navbar;
    let prefPage: PreferencesPage;

    beforeEach(async () => {
        listPage = new ListPage();
        calcPage = new CalculatorPage();
        navbar = new Navbar();
        prefPage = new PreferencesPage();
        // disable evil option "empty fields on module creation"
        await prefPage.navigateTo();
        await prefPage.disableEvilEmptyFields();
        await browser.sleep(200);
    });

    const calcTypes = testedCalcTypes;

    // for each calculator
    for (const ct of calcTypes) {
        if (ct === 22) {
            // omit 22 - Solveur is not tested here because it is not independent
            continue;
        }
        describe(" − clone all variations of calculator type [" + ct + "]", async () => {
            it("", async () => {
                await navbar.clickNewCalculatorButton();
                // click calculator button (instanciate)
                await listPage.clickMenuEntryForCalcType(ct);

                // get all select IDs outside Structures
                // get select IDs inside Structures
                // @TODO set configuration to every combination of <select> options

                // modify all <input> values and store them
                await calcPage.modifyAllInputValues();
                const sourceValues = await calcPage.storeAllInputValues();

                // clone calculator
                await scrollPageToTop();
                await calcPage.clickCloneCalcButton();
                await browser.sleep(300);

                // check existence of the cloned module
                expect(await navbar.getAllCalculatorTabs().count()).toBe(2);

                // @TODO check <select> values

                // read all <input> values and compare them to stored ones
                const cloneValues = await calcPage.storeAllInputValues();
                for (const k in cloneValues) {
                    expect(cloneValues[k]).toBeCloseTo(sourceValues[k]);
                }
            });
        });
    }

});
