import { browser, by, element } from "protractor";
import { Navbar } from "./navbar.po";
import { ListPage } from "./list.po";
import { SideNav } from "./sidenav.po";
import { PreferencesPage } from "./preferences.po";

/**
 * convert Mermaid formatted id ("flowchat-id-xx") to id
 * COPIED from Jalhyd since import is not possible.
 */
function removeMermaidIdFormat(id: string): string {
    if (id.startsWith("flowchart-")) {
        const i1 = id.indexOf("-");
        const i2 = id.lastIndexOf("-");
        id = id.substring(i1 + 1, i2);
    }
    return id;
}

describe("modules diagram", async () => {
    let navBar: Navbar;
    let listPage: ListPage;
    let sideNav: SideNav;
    let prefPage: PreferencesPage;

    beforeEach(async () => {
        listPage = new ListPage();
        navBar = new Navbar();
        sideNav = new SideNav();
        prefPage = new PreferencesPage();

        await prefPage.navigateTo();
    });

    it("- check click on a module opens matching calculator", async () => {
        //browser.manage().window().setPosition(2000, 30);

        // open predam calculator
        await navBar.clickNewCalculatorButton();
        await listPage.clickMenuEntryForCalcType(30);
        await browser.sleep(200);

        // open modules diagram
        await navBar.clickMenuButton();
        await browser.sleep(200);
        await sideNav.clickDiagramButton();
        await browser.sleep(200);

        // click first module
        const nodes = element.all(by.css("g.node.default"));
        const node0 = nodes.get(0);
        const n0id = removeMermaidIdFormat(await node0.getAttribute("id"));
        await node0.click();
        await browser.sleep(200);

        // check calculator is open
        const url = await browser.driver.getCurrentUrl();
        expect(url).toContain("/#/calculator/" + n0id);
    });
});
