import { browser, by, element } from "protractor";
import { CalculatorPage } from "./calculator.po";
import { ListPage } from "./list.po";
import { Navbar } from "./navbar.po";
import { PreferencesPage } from "./preferences.po";

describe("linked parameter - ", () => {
    let calcPage: CalculatorPage;
    let prefPage: PreferencesPage;
    let navBar: Navbar;
    let listPage: ListPage;

    beforeAll(() => {
        calcPage = new CalculatorPage();
        prefPage = new PreferencesPage();
        navBar = new Navbar();
        listPage = new ListPage();
    });

    beforeEach(async () => {
        // browser.manage().window().setPosition(2000, 30);

        // disable evil option "empty fields on module creation"
        await prefPage.navigateTo();
        await prefPage.disableEvilEmptyFields();
        await browser.sleep(200);

        await navBar.clickNewCalculatorButton();
    });

    it("delete linked module", async () => {
        // open "channel flow with hydraulic structures" example
        const examples = await element.all(by.css("#examples-list .load-example"));
        await examples[1].click();
        await browser.sleep(500);

        // select "up/downstream elevations of a reach" tab
        await navBar.clickCalculatorTab(1);
        await browser.sleep(500);

        // close "solver" calculator
        await navBar.middleClickCalculatorTab(3);

        // reselect "up/downstream elevations of a reach" tab
        await navBar.clickCalculatorTab(1);
        await browser.sleep(500);

        // close second "parallel structures" calculator
        await navBar.middleClickCalculatorTab(2);

        // close first "parallel structures" calculator
        await navBar.middleClickCalculatorTab(0);

        // check Z2 input is in "fixed" state in remaining calculator
        const inpZ2 = calcPage.getInputById("Z2");
        expect(await calcPage.inputIsInFixedMode(inpZ2)).toBe(true);
    });

    it("delete linked module and duplicate remaining one", async () => {
        // open "fish ladder: fall" calculator
        await listPage.clickMenuEntryForCalcType(12);
        await browser.sleep(200);

        // clone calculator
        await calcPage.clickCloneCalcButton();
        await browser.sleep(200);

        // set DH in link mode
        let inpDH = calcPage.getInputById("DH");
        await calcPage.setParamMode(inpDH, "link");
        await browser.sleep(200);

        // close 1st calculator
        await navBar.middleClickCalculatorTab(0);
        await browser.sleep(200);

        // check DH input is in "fixed" state in remaining calculator (not the aim of this test)
        inpDH = calcPage.getInputById("DH");
        expect(await calcPage.inputIsInFixedMode(inpDH)).toBe(true);

        // set DH to calculated mode
        await calcPage.setParamMode(inpDH, "cal");

        // clone calculator
        await calcPage.clickCloneCalcButton();
        await browser.sleep(200);

        // select 1st tab
        await navBar.clickCalculatorTab(0);
        await browser.sleep(500);

        // check DH input is in "calc" mode
        inpDH = calcPage.getInputById("DH");
        expect(await calcPage.inputIsInCalculatedMode(inpDH)).toBe(true);
    });
});
