import { ListPage } from "./list.po";
import { Navbar } from "./navbar.po";
import { browser } from "protractor";
import { CalculatorPage } from "./calculator.po";
import { PreferencesPage } from "./preferences.po";
import { cp } from "fs";
import { SideNav } from "./sidenav.po";

describe("Check results are reset after application settings modification - ", () => {
    let listPage: ListPage;
    let navBar: Navbar;
    let calcPage: CalculatorPage;
    let prefPage: PreferencesPage;
    let sideNav: SideNav;

    beforeAll(async () => {
        listPage = new ListPage();
        navBar = new Navbar();
        calcPage = new CalculatorPage();
        prefPage = new PreferencesPage();
        sideNav = new SideNav();
    });

    beforeEach(async () => {
        // browser.manage().window().setPosition(2000, 30);

        // disable evil option "empty fields on module creation"
        await prefPage.navigateTo();
        await prefPage.disableEvilEmptyFields();
        await browser.sleep(200);
    });

    async function runTestWithParamater(param: string, val1: number, val2: number) {
        // set starting compute precision
        const input = prefPage.getInputFromName(param);
        await input.clear();
        await browser.sleep(20);
        await input.sendKeys(val1.toString());
        await browser.sleep(200);

        // open "fish ladder: fall" calculator
        await navBar.clickNewCalculatorButton();
        await listPage.clickMenuEntryForCalcType(12);
        await browser.sleep(200);

        // click "compute" button
        const calcButton = calcPage.getCalculateButton();
        await calcButton.click();
        await browser.sleep(200);

        // results should be here
        let hasResults = await calcPage.hasResults();
        expect(hasResults).toBe(true);

        // reopen settings
        await navBar.clickMenuButton();
        await browser.sleep(200);
        const setupBtn = await sideNav.getSetupButton();
        await setupBtn.click();
        await browser.sleep(200);

        // modify compute precision
        await input.clear();
        await browser.sleep(20);
        await input.sendKeys(val2.toString());
        await browser.sleep(200);

        // back to calculator
        await navBar.openNthCalculator(0);

        // results should not be here
        hasResults = await calcPage.hasResults();
        expect(hasResults).toBe(false);

    }

    it("compute precision", async () => {
        await runTestWithParamater("cp", 0.001, 0.0001);
    });

    it("max iterations", async () => {
        await runTestWithParamater("nmi", 10, 100);
    });
});
